raw

Function raw 

pub fn raw(quant: Quant, dir: &[f32], range: f32) -> Vec<u8> 
The bytes VEMB RAW writes for a stored direction.

Little endian floats for the full precision form, one signed byte a coordinate for Q8, and for the binary form a run of 64 bit words with the first coordinate in the lowest bit of the first word.